@@ -1,6 +1,9 @@
 package PDF::API2;
 
-our $VERSION = '2.025'; # VERSION
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.030'; # VERSION
 
 use Carp;
 use Encode qw(:all);
@@ -21,9 +24,7 @@ use PDF::API2::Resource::Shading;
 
 use PDF::API2::NamedDestination;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
-our @FontDirs = ( (map { "$_/PDF/API2/fonts" } @INC), 
+our @FontDirs = ( (map { "$_/PDF/API2/fonts" } @INC),
                   qw[ /usr/share/fonts /usr/local/share/fonts c:/windows/fonts c:/winnt/fonts ] );
 
 =head1 NAME
@@ -112,7 +113,9 @@ sub new {
         $self->{'pdf'}->create_file($options{'-file'});
     }
     $self->{'infoMeta'}=[qw(Author CreationDate ModDate Creator Producer Title Subject Keywords)];
-    $self->info('Producer' => "PDF::API2 $VERSION [$^O]");
+
+    my $version = eval { $PDF::API2::VERSION } || '(Unreleased Version)';
+    $self->info('Producer' => "PDF::API2 $version [$^O]");
 
     return $self;
 }
@@ -295,6 +298,18 @@ Document outline visible after Full-screen mode.
 
 Set the default print setting for page scaling to none.
 
+=item -simplex
+
+Print single-sided by default.
+
+=item -duplexflipshortedge
+
+Print duplex by default and flip on the short edge of the sheet.
+
+=item -duplexfliplongedge
+
+Print duplex by default and flip on the long edge of the sheet.
+
 =back
 
 B<Initial Page Options>:
@@ -458,6 +473,16 @@ sub preferences {
         $self->{'catalog'}->{'ViewerPreferences'}->{'PrintScaling'} = PDFName('None');
     }
 
+    if ($options{'-simplex'}) {
+        $self->{'catalog'}->{'ViewerPreferences'}->{'Duplex'} = PDFName('Simplex');
+    }
+    elsif ($options{'-duplexfliplongedge'}) {
+        $self->{'catalog'}->{'ViewerPreferences'}->{'Duplex'} = PDFName('DuplexFlipLongEdge');
+    }
+    elsif ($options{'-duplexflipshortedge'}) {
+        $self->{'catalog'}->{'ViewerPreferences'}->{'Duplex'} = PDFName('DuplexFlipShortEdge');
+    }
+
     # Open Action
     if ($options{'-firstpage'}) {
         my ($page, %args) = @{$options{-firstpage}};
@@ -567,7 +592,7 @@ sub isEncrypted {
     my $self=shift @_;
     return(defined($self->{pdf}->{'Encrypt'}) ? 1 : 0);
 }
-    
+
 =item %infohash = $pdf->info(%infohash)
 
 Gets/sets the info structure of the document.
@@ -619,7 +644,7 @@ sub info {
       foreach my $k (@{$self->{infoMeta}}) {
         next unless(defined $self->{pdf}->{'Info'}->{$k});
         $opt{$k}=$self->{pdf}->{'Info'}->{$k}->val;
-        if ((unpack('n',$opt{$k})==0xfffe) or (unpack('n',$opt{$k})==0xfeff)) 
+        if ((unpack('n',$opt{$k})==0xfffe) or (unpack('n',$opt{$k})==0xfeff))
         {
             $opt{$k} = decode('UTF-16', $self->{pdf}->{'Info'}->{$k}->val);
         }
@@ -642,7 +667,7 @@ B<Example:>
 
 =cut
 
-sub infoMetaAttributes 
+sub infoMetaAttributes
 {
     my ($self,@attr) = @_;
     if(scalar @attr > 0) {
@@ -717,23 +742,23 @@ B<Example:>
 sub xmpMetadata {
     my $self=shift @_;
 
-    if(!defined($self->{catalog}->{Metadata})) 
+    if(!defined($self->{catalog}->{Metadata}))
     {
             $self->{catalog}->{Metadata}=PDFDict();
             $self->{catalog}->{Metadata}->{Type}=PDFName('Metadata');
             $self->{catalog}->{Metadata}->{Subtype}=PDFName('XML');
             $self->{pdf}->new_obj($self->{catalog}->{Metadata});
-    } 
-    else 
+    }
+    else
     {
         $self->{catalog}->{Metadata}->realise;
         $self->{catalog}->{Metadata}->{' stream'}=unfilter($self->{catalog}->{Metadata}->{Filter}, $self->{catalog}->{Metadata}->{' stream'});
         delete $self->{catalog}->{Metadata}->{' nofilt'};
         delete $self->{catalog}->{Metadata}->{Filter};
     }
-    
+
     my $md=$self->{catalog}->{Metadata};
-    
+
     if(defined $_[0])
     {
         $md->{' stream'}=$_[0];
@@ -784,13 +809,13 @@ B<Example:>
         -start => 1,
         -prefix => 'A-'
     });
-    
+
     # Numbering for Appendix B
     $pdf->pageLabel( 36, {
         -start => 1,
         -prefix => 'B-'
     });
-    
+
     # Numbering for the Index
     $pdf->pageLabel(40, {
         -style => 'Roman'
@@ -818,7 +843,7 @@ sub pageLabel {
                             $opts->{'-style'} eq 'roman' ? 'r' :
                             $opts->{'-style'} eq 'Alpha' ? 'A' :
                             $opts->{'-style'} eq 'alpha' ? 'a' : 'D');
-                          
+
         if (defined $opts->{'-prefix'}) {
             $d->{'P'} = PDFStr($opts->{'-prefix'});
         }
@@ -1023,15 +1048,8 @@ Returns a new page object.  By default, the page is added to the end
 of the document.  If you include an existing page number, the new page
 will be inserted in that position, pushing existing pages back.
 
-$page_number can also have one of the following values:
-
-=over
-
-=item -1 inserts the new page as the second-last page
-
-=item 0 inserts the page as the last page
-
-=back
+If $page_number is -1, the new page is inserted as the second-last page;
+if $page_number is 0, the new page is inserted as the last page.
 
 B<Example:>
 
@@ -1087,154 +1105,147 @@ B<Example:>
 =cut
 
 sub openpage {
-    my $self=shift @_;
-    my $index=shift @_||0;
-    my ($page,$rotate,$media,$trans);
+    my $self = shift();
+    my $index = shift() || 0;
+    my ($page, $rotate, $media, $trans);
 
-    if($index==0) 
-    {
-        $page=$self->{pagestack}->[-1];
-    } 
-    elsif($index<0) 
-    {
-        $page=$self->{pagestack}->[$index];
-    } 
-    else 
-    {
-        $page=$self->{pagestack}->[$index-1];
+    if ($index == 0) {
+        $page = $self->{'pagestack'}->[-1];
     }
-    return undef unless(ref $page);
-    
-    if(ref($page) ne 'PDF::API2::Page') 
-    {
-        bless($page,'PDF::API2::Page');
-        $page->{' apipdf'}=$self->{pdf};
-        $page->{' api'}=$self;
-        $self->{pdf}->out_obj($page);
-        if(($rotate=$page->find_prop('Rotate')) && (!defined($page->{' fixed'}) || $page->{' fixed'}<1)) 
-        {
-            $rotate=($rotate->val+360)%360;
+    elsif ($index<0) {
+        $page = $self->{'pagestack'}->[$index];
+    }
+    else {
+        $page = $self->{'pagestack'}->[$index - 1];
+    }
+    return unless ref($page);
 
-            if($rotate!=0 && !$self->default('nounrotate')) {
-                $page->{Rotate}=PDFNum(0);
+    if (ref($page) ne 'PDF::API2::Page') {
+        bless $page, 'PDF::API2::Page';
+        $page->{' apipdf'} = $self->{'pdf'};
+        $page->{' api'} = $self;
+        $self->{'pdf'}->out_obj($page);
+        if (($rotate = $page->find_prop('Rotate')) && (!defined($page->{' fixed'}) || $page->{' fixed'} < 1)) {
+            $rotate = ($rotate->val() + 360) % 360;
+
+            if ($rotate != 0 && !$self->default('nounrotate')) {
+                $page->{'Rotate'} = PDFNum(0);
                 foreach my $mediatype (qw( MediaBox CropBox BleedBox TrimBox ArtBox )) {
-                    if($media=$page->find_prop($mediatype)) {
-                        $media=[ map{ $_->val } $media->elementsof ];
-                    } else {
-                        $media=[0,0,612,792];
-                        next if($mediatype ne 'MediaBox');
+                    if ($media = $page->find_prop($mediatype)) {
+                        $media = [ map { $_->val() } $media->elementsof() ];
                     }
-                    if($rotate==90) {
-                        $trans="0 -1 1 0 0 $media->[2] cm" if($mediatype eq 'MediaBox');
-                        $media=[$media->[1],$media->[0],$media->[3],$media->[2]];
-                    } elsif($rotate==180) {
-                        $trans="-1 0 0 -1 $media->[2] $media->[3] cm" if($mediatype eq 'MediaBox');
-                    } elsif($rotate==270) {
-                        $trans="0 1 -1 0 $media->[3] 0 cm" if($mediatype eq 'MediaBox');
-                        $media=[$media->[1],$media->[0],$media->[3],$media->[2]];
+                    else {
+                        $media = [0, 0, 612, 792];
+                        next if $mediatype ne 'MediaBox';
                     }
-                    $page->{$mediatype}=PDFArray(map { PDFNum($_) } @{$media});
+                    if ($rotate == 90) {
+                        $trans = "0 -1 1 0 0 $media->[2] cm" if $mediatype eq 'MediaBox';
+                        $media = [$media->[1], $media->[0], $media->[3], $media->[2]];
+                    }
+                    elsif ($rotate == 180) {
+                        $trans = "-1 0 0 -1 $media->[2] $media->[3] cm" if $mediatype eq 'MediaBox';
+                    }
+                    elsif ($rotate == 270) {
+                        $trans = "0 1 -1 0 $media->[3] 0 cm" if $mediatype eq 'MediaBox';
+                        $media = [$media->[1], $media->[0], $media->[3], $media->[2]];
+                    }
+                    $page->{$mediatype} = PDFArray(map { PDFNum($_) } @$media);
                 }
-            } else {
-                $trans="";
             }
-        } else {
-            $trans="";
+            else {
+                $trans = '';
+            }
+        }
+        else {
+            $trans = '';
         }
 
-        if(defined $page->{Contents} && (!defined($page->{' fixed'}) || $page->{' fixed'}<1) ) {
-            $page->fixcontents;
-            my $uncontent=$page->{Contents};
-            delete $page->{Contents};
-            my $content=$page->gfx();
+        if (defined $page->{'Contents'} && (!defined($page->{' fixed'}) || $page->{' fixed'} < 1)) {
+            $page->fixcontents();
+            my $uncontent = delete $page->{'Contents'};
+            my $content = $page->gfx();
             $content->add(" $trans ");
 
-            if($self->default('pageencaps'))
-            {
-                $content->{' stream'}.=" q ";
+            if ($self->default('pageencaps')) {
+                $content->{' stream'} .= ' q ';
             }
-            foreach my $k ($uncontent->elementsof) 
-            {
-                $k->realise;
-                    $content->{' stream'}.=" ".unfilter($k->{Filter}, $k->{' stream'})." ";
+            foreach my $k ($uncontent->elementsof()) {
+                $k->realise();
+                $content->{' stream'} .= ' ' . unfilter($k->{'Filter'}, $k->{' stream'}) . ' ';
             }
-            if($self->default('pageencaps'))
-            {
-                $content->{' stream'}.=" Q ";
+            if ($self->default('pageencaps')) {
+                $content->{' stream'} .= ' Q ';
             }
 
             ## $content->{Length}=PDFNum(length($content->{' stream'}));
-            # this  will be fixed by the following code or content or filters
+            # this will be fixed by the following code or content or filters
 
             ## if we like compress we will do it now to do quicker saves
-            if($self->{forcecompress}>0){
-            ##    $content->compressFlate;
-                $content->{' stream'}=dofilter($content->{Filter}, $content->{' stream'});
-                $content->{' nofilt'}=1;
-                delete $content->{-docompress};
-                $content->{Length}=PDFNum(length($content->{' stream'}));
+            if ($self->{'forcecompress'} > 0) {
+                ## $content->compressFlate;
+                $content->{' stream'} = dofilter($content->{'Filter'}, $content->{' stream'});
+                $content->{' nofilt'} = 1;
+                delete $content->{'-docompress'};
+                $content->{'Length'} = PDFNum(length($content->{' stream'}));
             }
-            $page->{' fixed'}=1;
         }
+        $page->{' fixed'} = 1;
     }
 
-    $self->{pdf}->out_obj($page);
-    $self->{pdf}->out_obj($self->{pages});
-    $page->{' apipdf'}=$self->{pdf};
-    $page->{' api'}=$self;
-    $page->{' reopened'}=1;
-    return($page);
+    $self->{'pdf'}->out_obj($page);
+    $self->{'pdf'}->out_obj($self->{'pages'});
+    $page->{' apipdf'} = $self->{'pdf'};
+    $page->{' api'} = $self;
+    $page->{' reopened'} = 1;
+    return $page;
 }
 
 
-# $target_object = walk_obj $obj_cache, $source_pdf, $target_pdf, $source_object [, @keys_to_copy ]
-
 sub walk_obj {
-    my ($objs,$spdf,$tpdf,$obj,@keys)=@_;
+    my ($object_cache, $source_pdf, $target_pdf, $source_object, @keys) = @_;
 
-    my $tobj;
-
-
-    if(ref($obj)=~/Objind$/) {
-        $obj->realise;
+    if (ref($source_object) =~ /Objind$/) {
+        $source_object->realise();
     }
 
-    return($objs->{scalar $obj}) if(defined $objs->{scalar $obj});
-####die "infinite loop while copying objects" if($obj->{' copied'});
+    return $object_cache->{scalar $source_object} if defined $object_cache->{scalar $source_object};
+####die "infinite loop while copying objects" if($source_object->{' copied'});
 
-    $tobj=$obj->copy($spdf); ## thanks to: yaheath // Fri, 17 Sep 2004
-    
-####$obj->{' copied'}=1;
-    $tpdf->new_obj($tobj) if($obj->is_obj($spdf));
+    my $target_object = $source_object->copy($source_pdf); ## thanks to: yaheath // Fri, 17 Sep 2004
 
-    $objs->{scalar $obj}=$tobj;
+####$source_object->{' copied'}=1;
+    $target_pdf->new_obj($target_object) if $source_object->is_obj($source_pdf);
 
-    if(ref($obj)=~/Array$/) {
-        $tobj->{' val'}=[];
-        foreach my $k ($obj->elementsof) {
-            $k->realise if(ref($k)=~/Objind$/);
-            $tobj->add_elements(walk_obj($objs,$spdf,$tpdf,$k));
+    $object_cache->{scalar $source_object} = $target_object;
+
+    if (ref($source_object) =~ /Array$/) {
+        $target_object->{' val'} = [];
+        foreach my $k ($source_object->elementsof()) {
+            $k->realise() if ref($k) =~ /Objind$/;
+            $target_object->add_elements(walk_obj($object_cache, $source_pdf, $target_pdf, $k));
         }
-    } elsif(ref($obj)=~/Dict$/) {
-        @keys=keys(%{$tobj}) if(scalar @keys <1);
+    }
+    elsif (ref($source_object) =~ /Dict$/) {
+        @keys = keys(%$target_object) unless scalar @keys;
         foreach my $k (@keys) {
-            next if($k=~/^ /);
-            next unless(defined($obj->{$k}));
-            $tobj->{$k}=walk_obj($objs,$spdf,$tpdf,$obj->{$k});
+            next if $k =~ /^ /;
+            next unless defined $source_object->{$k};
+            $target_object->{$k} = walk_obj($object_cache, $source_pdf, $target_pdf, $source_object->{$k});
         }
-        if($obj->{' stream'}) {
-            if($tobj->{Filter}) {
-                $tobj->{' nofilt'}=1;
-            } else {
-                delete $tobj->{' nofilt'};
-                $tobj->{Filter}=PDFArray(PDFName('FlateDecode'));
+        if ($source_object->{' stream'}) {
+            if ($target_object->{'Filter'}) {
+                $target_object->{' nofilt'} = 1;
             }
-            $tobj->{' stream'}=$obj->{' stream'};
+            else {
+                delete $target_object->{' nofilt'};
+                $target_object->{'Filter'} = PDFArray(PDFName('FlateDecode'));
+            }
+            $target_object->{' stream'} = $source_object->{' stream'};
         }
     }
-    delete $tobj->{' streamloc'};
-    delete $tobj->{' streamsrc'};
-    return($tobj);
+    delete $target_object->{' streamloc'};
+    delete $target_object->{' streamsrc'};
+    return $target_object;
 }
 
 =item $xoform = $pdf->importPageIntoForm($source_pdf, $source_page_number)
@@ -1258,7 +1269,7 @@ B<Example:>
     $xo = $pdf->importPageIntoForm($old, 2);
 
     # Add it to the new PDF's first page at 1/2 scale
-    $gfx->formimage($xo, 0, 0, 0.5); 
+    $gfx->formimage($xo, 0, 0, 0.5);
 
     $pdf->saveas('our/new.pdf');
 
@@ -1384,7 +1395,7 @@ sub import_page {
     unless (ref($s_pdf) and $s_pdf->isa('PDF::API2')) {
         die "Invalid usage: 1st argument must be PDF::API2 instance, not: " . ref($s_pdf);
     }
-	
+
     if(ref($s_idx) eq 'PDF::API2::Page') {
         $s_page=$s_idx;
     } else {
@@ -1659,10 +1670,9 @@ See Also: L<PDF::API2::Resource::Font::CoreFont>.
 =cut
 
 sub corefont {
-    my ($self,$name,@opts)=@_;
+    my ($self,$name,%opts)=@_;
     require PDF::API2::Resource::Font::CoreFont;
-    my $obj=PDF::API2::Resource::Font::CoreFont->new_api($self,$name,@opts);
-    $self->resource('Font',$obj->name,$obj);
+    my $obj=PDF::API2::Resource::Font::CoreFont->new_api($self,$name,%opts);
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1713,8 +1723,6 @@ sub psfont {
     require PDF::API2::Resource::Font::Postscript;
     my $obj=PDF::API2::Resource::Font::Postscript->new_api($self,$psf,%opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1766,8 +1774,6 @@ sub ttfont {
     require PDF::API2::Resource::CIDFont::TrueType;
     my $obj = PDF::API2::Resource::CIDFont::TrueType->new_api($self, $file, %opts);
 
-    $self->resource('Font', $obj->name, $obj, $self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if $opts{-unicodemap};
     return $obj;
@@ -1802,8 +1808,6 @@ sub cjkfont {
     require PDF::API2::Resource::CIDFont::CJKFont;
     my $obj=PDF::API2::Resource::CIDFont::CJKFont->new_api($self,$name,%opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
     return($obj);
@@ -1847,12 +1851,10 @@ See Also: L<PDF::API2::Resource::Font::SynFont>
 =cut
 
 sub synfont {
-    my ($self,@opts)=@_;
+    my ($self,%opts)=@_;
 
     require PDF::API2::Resource::Font::SynFont;
-    my $obj=PDF::API2::Resource::Font::SynFont->new_api($self,@opts);
-
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
+    my $obj=PDF::API2::Resource::Font::SynFont->new_api($self,%opts);
 
     $self->{pdf}->out_obj($self->{pages});
     $obj->tounicodemap if($opts{-unicodemap}==1);
@@ -1873,8 +1875,6 @@ sub bdfont {
     require PDF::API2::Resource::Font::BdFont;
     my $obj=PDF::API2::Resource::Font::BdFont->new_api($self,@opts);
 
-    $self->resource('Font',$obj->name,$obj,$self->{reopened});
-
     $self->{pdf}->out_obj($self->{pages});
     ## $obj->tounicodemap; # does not support unicode!
     return($obj);
@@ -1917,7 +1917,7 @@ sub unifont {
 
 =item $jpeg = $pdf->image_jpeg($file)
 
-Imports and returns a new JPEG image object.
+Imports and returns a new JPEG image object.  C<$file> may be either a filename or a filehandle.
 
 =cut
 
@@ -1927,15 +1927,13 @@ sub image_jpeg {
     require PDF::API2::Resource::XObject::Image::JPEG;
     my $obj=PDF::API2::Resource::XObject::Image::JPEG->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
 
 =item $tiff = $pdf->image_tiff($file)
 
-Imports and returns a new TIFF image object.
+Imports and returns a new TIFF image object.  C<$file> may be either a filename or a filehandle.
 
 =cut
 
@@ -1945,15 +1943,13 @@ sub image_tiff {
     require PDF::API2::Resource::XObject::Image::TIFF;
     my $obj=PDF::API2::Resource::XObject::Image::TIFF->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
 
 =item $pnm = $pdf->image_pnm($file)
 
-Imports and returns a new PNM image object.
+Imports and returns a new PNM image object.  C<$file> may be either a filename or a filehandle.
 
 =cut
 
@@ -1963,15 +1959,13 @@ sub image_pnm {
     require PDF::API2::Resource::XObject::Image::PNM;
     my $obj=PDF::API2::Resource::XObject::Image::PNM->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
 
 =item $png = $pdf->image_png($file)
 
-Imports and returns a new PNG image object.
+Imports and returns a new PNG image object.  C<$file> may be either a filename or a filehandle.
 
 =cut
 
@@ -1981,15 +1975,13 @@ sub image_png {
     require PDF::API2::Resource::XObject::Image::PNG;
     my $obj=PDF::API2::Resource::XObject::Image::PNG->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
 
 =item $gif = $pdf->image_gif($file)
 
-Imports and returns a new GIF image object.
+Imports and returns a new GIF image object.  C<$file> may be either a filename or a filehandle.
 
 =cut
 
@@ -1999,8 +1991,6 @@ sub image_gif {
     require PDF::API2::Resource::XObject::Image::GIF;
     my $obj=PDF::API2::Resource::XObject::Image::GIF->new_api($self,$file);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2019,8 +2009,6 @@ sub image_gd {
     require PDF::API2::Resource::XObject::Image::GD;
     my $obj=PDF::API2::Resource::XObject::Image::GD->new_api($self,$gd,undef,%opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2046,8 +2034,6 @@ sub colorspace_act {
     require PDF::API2::Resource::ColorSpace::Indexed::ACTFile;
     my $obj=PDF::API2::Resource::ColorSpace::Indexed::ACTFile->new_api($self,$file);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2064,8 +2050,6 @@ sub colorspace_web {
     require PDF::API2::Resource::ColorSpace::Indexed::WebColor;
     my $obj=PDF::API2::Resource::ColorSpace::Indexed::WebColor->new_api($self);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2084,8 +2068,6 @@ sub colorspace_hue {
     require PDF::API2::Resource::ColorSpace::Indexed::Hue;
     my $obj=PDF::API2::Resource::ColorSpace::Indexed::Hue->new_api($self);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2112,8 +2094,6 @@ sub colorspace_separation {
     require PDF::API2::Resource::ColorSpace::Separation;
     my $obj=PDF::API2::Resource::ColorSpace::Separation->new_api($self,$name,@clr);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2122,7 +2102,7 @@ sub colorspace_separation {
 
 Returns a new DeviceN colorspace object based on the parameters.
 
-B<Example:> 
+B<Example:>
 
     $cy = $pdf->colorspace_separation('Cyan',    '%f000');
     $ma = $pdf->colorspace_separation('Magenta', '%0f00');
@@ -2141,12 +2121,10 @@ colorspace specified.
 sub colorspace_devicen {
     my ($self,$clrs,$samples)=@_;
     $samples||=2;
-    
+
     require PDF::API2::Resource::ColorSpace::DeviceN;
     my $obj=PDF::API2::Resource::ColorSpace::DeviceN->new_api($self,$clrs,$samples);
 
-    $self->resource('ColorSpace',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2177,8 +2155,6 @@ sub xo_code128 {
     require PDF::API2::Resource::XObject::Form::BarCode::code128;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::code128->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2189,8 +2165,6 @@ sub xo_codabar {
     require PDF::API2::Resource::XObject::Form::BarCode::codabar;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::codabar->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2201,8 +2175,6 @@ sub xo_2of5int {
     require PDF::API2::Resource::XObject::Form::BarCode::int2of5;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::int2of5->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2213,8 +2185,6 @@ sub xo_3of9 {
     require PDF::API2::Resource::XObject::Form::BarCode::code3of9;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::code3of9->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2225,8 +2195,6 @@ sub xo_ean13 {
     require PDF::API2::Resource::XObject::Form::BarCode::ean13;
     my $obj=PDF::API2::Resource::XObject::Form::BarCode::ean13->new_api($self,@opts);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2248,8 +2216,6 @@ sub xo_form {
 
     my $obj=PDF::API2::Resource::XObject::Form::Hybrid->new_api($self);
 
-    $self->resource('XObject',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2265,8 +2231,6 @@ sub egstate {
 
     my $obj=PDF::API2::Resource::ExtGState->new_api($self,pdfkey());
 
-    $self->resource('ExtGState',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2282,8 +2246,6 @@ sub pattern {
 
     my $obj=PDF::API2::Resource::Pattern->new_api($self,undef,%opts);
 
-    $self->resource('Pattern',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2299,8 +2261,6 @@ sub shading {
 
     my $obj=PDF::API2::Resource::Shading->new_api($self,undef,%opts);
 
-    $self->resource('Shading',$obj->name,$obj);
-
     $self->{pdf}->out_obj($self->{pages});
     return($obj);
 }
@@ -2337,20 +2297,20 @@ sub named_destination
     $root->{Names}->{$cat}->{-vals}||={};
     $root->{Names}->{$cat}->{Limits}||=PDFArray();
     $root->{Names}->{$cat}->{Names}||=PDFArray();
-    
+
     unless(defined $obj)
     {
         $obj=PDF::API2::NamedDestination->new_api($self);
     }
     $root->{Names}->{$cat}->{-vals}->{$name}=$obj;
-    
+
     my @names=sort {$a cmp $b} keys %{$root->{Names}->{$cat}->{-vals}};
-    
+
     $root->{Names}->{$cat}->{Limits}->{' val'}->[0]=PDFStr($names[0]);
     $root->{Names}->{$cat}->{Limits}->{' val'}->[1]=PDFStr($names[-1]);
-    
+
     @{$root->{Names}->{$cat}->{Names}->{' val'}}=();
-    
+
     foreach my $k (@names)
     {
         push @{$root->{Names}->{$cat}->{Names}->{' val'}},
@@ -2362,85 +2322,14 @@ sub named_destination
 
 =back
 
-=head1 RESOURCE METHODS
-
-=over
-
-=item $pdf->resource($type, $key, $obj, $force)
-
-Adds a resource to the global PDF tree.
-
-B<Example:>
-
-    $pdf->resource('Font', $fontkey, $fontobj);
-    $pdf->resource('XObject', $imagekey, $imageobj);
-    $pdf->resource('Shading', $shadekey, $shadeobj);
-    $pdf->resource('ColorSpace', $spacekey, $speceobj);
-
-B<Note:> You only have to add the required resources if they are NOT
-handled by the font, image, shade or space methods.
-
-=cut
-
-sub resource 
-{
-    return(undef);
-    my ($self, $type, $key, $obj, $force) = @_;
-
-    $self->{pages}->{Resources}||=PDFDict();
-
-    my $dict=$self->{pages}->{Resources};
-    $dict->realise if(ref($dict)=~/Objind$/);
-
-    $self->{pdf}->new_obj($dict) unless($dict->is_obj($self->{pdf}));
-
-    $dict->{$type}=$dict->{$type} || PDFDict();
-    $dict->{$type}->realise if(ref($dict->{$type})=~/Objind$/);
-
-    if(defined($obj)) 
-    {
-        if($force) 
-        {
-            $dict->{$type}->{$key}=$obj;
-        } 
-        else 
-        {
-            $dict->{$type}->{$key}=$dict->{$type}->{$key} || $obj;
-        }
-
-        $self->{pdf}->out_obj($dict)
-            if($dict->is_obj($self->{pdf}));
-
-        $self->{pdf}->out_obj($dict->{$type})
-            if($dict->{$type}->is_obj($self->{pdf}));
-
-        $self->{pdf}->out_obj($obj)
-            if($obj->is_obj($self->{pdf}));
-
-        $self->{pdf}->out_obj($self->{pages});
-
-        return($dict);
-    }
-    return($dict->{$type}->{$key} || undef);
-}
-
 1;
 
 __END__
 
-=back
-
 =head1 KNOWN ISSUES
 
 This module does not work with perl's -l command-line switch.
 
-PDFs using cross-reference streams instead of cross-reference tables
-are not yet supported.  Cross-reference streams were added as an
-option in version 1.5 of the PDF spec, but were only used infrequently
-until Adobe Acrobat 9 started using them by default.  A patch would be
-welcome -- see the PDF 1.7 specification, sections 7.5.4 and 7.5.8 for
-implementation details.
-
 =head1 AUTHOR
 
 PDF::API2 was originally written by Alfred Reibenschuh.
