@@ -12,7 +12,9 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::Utils;
 
-our $VERSION = '2.020'; # VERSION
+use strict;
+
+our $VERSION = '2.030'; # VERSION
 
 =head1 NAME
 
@@ -26,8 +28,6 @@ A set of utility functions to save the fingers of the PDF library users!
 
 =cut
 
-use strict;
-
 use PDF::API2::Basic::PDF::Array;
 use PDF::API2::Basic::PDF::Bool;
 use PDF::API2::Basic::PDF::Dict;
@@ -40,9 +40,8 @@ use PDF::API2::Basic::PDF::Literal;
 use Exporter;
 use vars qw(@EXPORT @ISA);
 @ISA = qw(Exporter);
-@EXPORT = qw(PDFBool PDFArray PDFDict PDFLiteral PDFName PDFNull
-             PDFNum PDFStr PDFStrHex PDFUtf asPDFBool asPDFName
-             asPDFNum asPDFStr);
+@EXPORT = qw(PDFBool PDFArray PDFDict PDFName PDFNull
+             PDFNum PDFStr PDFStrHex PDFUtf);
 
 =head2 PDFBool
 
@@ -138,14 +137,4 @@ sub PDFUtf {
     return $string;
 }
 
-=head2 PDFLiteral
-
-Creates a pdf-literal via PDF::API2::Basic::PDF::Literal->new
-
-=cut
-
-sub PDFLiteral {
-    return PDF::API2::Basic::PDF::Literal->new(@_);
-}
-
 1;
