@@ -1,16 +1,17 @@
 package PDF::API2::Resource::BaseFont;
 
-our $VERSION = '2.025'; # VERSION
-
 use base 'PDF::API2::Resource';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.030'; # VERSION
+
 use Compress::Zlib;
 use Encode qw(:all);
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2::Util;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
 =head1 NAME
 
 PDF::API2::Resource::BaseFont - Base class for font resources
@@ -60,7 +61,7 @@ sub data { return( $_[0]->{' data'} ); }
 
 =item $descriptor = $font->descrByData()
 
-Returns the fonts FontDescriptor key-structure based on the fonts data.
+Returns the font's FontDescriptor key-structure based on the font's data.
 
 =cut
 
@@ -94,11 +95,11 @@ sub descrByData {
             $des->{Style}=PDFDict();
             $des->{Style}->{Panose}=PDFStrHex($self->data->{panose});
         }
-        $des->{FontFamily}=PDFStr($self->data->{fontfamily}) 
+        $des->{FontFamily}=PDFStr($self->data->{fontfamily})
             if(defined $self->data->{fontfamily});
-        $des->{FontWeight}=PDFNum($self->data->{fontweight}) 
+        $des->{FontWeight}=PDFNum($self->data->{fontweight})
             if(defined $self->data->{fontweight});
-        $des->{FontStretch}=PDFName($self->data->{fontstretch}) 
+        $des->{FontStretch}=PDFName($self->data->{fontstretch})
             if(defined $self->data->{fontstretch});
  #   }
 
@@ -107,7 +108,7 @@ sub descrByData {
 
 sub tounicodemap {
     my $self=shift @_;
-    
+
     return($self) if(defined $self->{ToUnicode});
 
     my $cmap=qq|\%\% Custom\n\%\% CMap\n\%\%\n/CIDInit /ProcSet findresource begin\n|;
@@ -135,7 +136,7 @@ sub tounicodemap {
     } else {
         # everything else is single byte font
         $cmap.=qq|1 begincodespacerange\n<00> <FF>\nendcodespacerange\n|;
-        $cmap.=qq|256 beginbfchar\n|; 
+        $cmap.=qq|256 beginbfchar\n|;
         for(my $j=0; $j<256;$j++) {
             $cmap.=sprintf(qq|<%02X> <%04X>\n|,$j,$self->uniByEnc($j));
         }
@@ -150,7 +151,7 @@ sub tounicodemap {
     $tuni->{CIDSystemInfo}->{Registry}=PDFStr($self->name);
     $tuni->{CIDSystemInfo}->{Ordering}=PDFStr('XYZ');
     $tuni->{CIDSystemInfo}->{Supplement}=PDFNum(0);
-    
+
     $self->{' apipdf'}->new_obj($tuni);
     $tuni->{' nofilt'}=1;
     $tuni->{' stream'}=Compress::Zlib::compress($cmap);
@@ -168,7 +169,7 @@ sub tounicodemap {
 
 =item $name = $font->fontname()
 
-Returns the fonts name (aka. display-name).
+Returns the font's name (aka. display-name).
 
 =cut
 
@@ -176,7 +177,7 @@ sub fontname { return( $_[0]->data->{fontname} ); }
 
 =item $name = $font->altname()
 
-Returns the fonts alternative-name (aka. windows-name for a postscript font).
+Returns the font's alternative-name (aka. windows-name for a postscript font).
 
 =cut
 
@@ -184,7 +185,7 @@ sub altname { return( $_[0]->data->{altname} ); }
 
 =item $name = $font->subname()
 
-Returns the fonts subname (aka. font-variant, schriftschnitt).
+Returns the font's subname (aka. font-variant, schriftschnitt).
 
 =cut
 
@@ -192,7 +193,7 @@ sub subname { return( $_[0]->data->{subname} ); }
 
 =item $name = $font->apiname()
 
-Returns the fonts name to be used internally (should be equal to $font->name).
+Returns the font's name to be used internally (should be equal to $font->name).
 
 =cut
 
@@ -200,7 +201,7 @@ sub apiname { return( $_[0]->data->{apiname} ); }
 
 =item $issymbol = $font->issymbol()
 
-Returns the fonts symbol flag.
+Returns the font's symbol flag.
 
 =cut
 
@@ -208,7 +209,7 @@ sub issymbol { return( $_[0]->data->{issymbol} ); }
 
 =item $iscff = $font->iscff()
 
-Returns the fonts compact-font-format flag.
+Returns the font's compact-font-format flag.
 
 =cut
 
@@ -222,7 +223,7 @@ sub iscff { return( $_[0]->data->{iscff} ); }
 
 =item ($llx, $lly, $urx, $ury) = $font->fontbbox()
 
-Returns the fonts bounding-box.
+Returns the font's bounding-box.
 
 =cut
 
@@ -230,7 +231,7 @@ sub fontbbox { return( @{$_[0]->data->{fontbbox}} ); }
 
 =item $capheight = $font->capheight()
 
-Returns the fonts capheight value.
+Returns the font's capheight value.
 
 =cut
 
@@ -238,7 +239,7 @@ sub capheight { return( $_[0]->data->{capheight} ); }
 
 =item $xheight = $font->xheight()
 
-Returns the fonts xheight value.
+Returns the font's xheight value.
 
 =cut
 
@@ -246,7 +247,7 @@ sub xheight { return( $_[0]->data->{xheight} ); }
 
 =item $missingwidth = $font->missingwidth()
 
-Returns the fonts missingwidth value.
+Returns the font's missingwidth value.
 
 =cut
 
@@ -254,7 +255,7 @@ sub missingwidth { return( $_[0]->data->{missingwidth} ); }
 
 =item $maxwidth = $font->maxwidth()
 
-Returns the fonts maxwidth value.
+Returns the font's maxwidth value.
 
 =cut
 
@@ -262,7 +263,7 @@ sub maxwidth { return( $_[0]->data->{maxwidth} ); }
 
 =item $avgwidth = $font->avgwidth()
 
-Returns the fonts avgwidth value.
+Returns the font's avgwidth value.
 
 =cut
 
@@ -329,7 +330,7 @@ sub avgwidth {
 
 =item $flags = $font->flags()
 
-Returns the fonts flags value.
+Returns the font's flags value.
 
 =cut
 
@@ -337,7 +338,7 @@ sub flags { return( $_[0]->data->{flags} ); }
 
 =item $stemv = $font->stemv()
 
-Returns the fonts stemv value.
+Returns the font's stemv value.
 
 =cut
 
@@ -345,7 +346,7 @@ sub stemv { return( $_[0]->data->{stemv} ); }
 
 =item $stemh = $font->stemh()
 
-Returns the fonts stemh value.
+Returns the font's stemh value.
 
 =cut
 
@@ -353,7 +354,7 @@ sub stemh { return( $_[0]->data->{stemh} ); }
 
 =item $italicangle = $font->italicangle()
 
-Returns the fonts italicangle value.
+Returns the font's italicangle value.
 
 =cut
 
@@ -361,7 +362,7 @@ sub italicangle { return( $_[0]->data->{italicangle} ); }
 
 =item $isfixedpitch = $font->isfixedpitch()
 
-Returns the fonts isfixedpitch flag.
+Returns the font's isfixedpitch flag.
 
 =cut
 
@@ -369,7 +370,7 @@ sub isfixedpitch { return( $_[0]->data->{isfixedpitch} ); }
 
 =item $underlineposition = $font->underlineposition()
 
-Returns the fonts underlineposition value.
+Returns the font's underlineposition value.
 
 =cut
 
@@ -377,7 +378,7 @@ sub underlineposition { return( $_[0]->data->{underlineposition} ); }
 
 =item $underlinethickness = $font->underlinethickness()
 
-Returns the fonts underlinethickness value.
+Returns the font's underlinethickness value.
 
 =cut
 
@@ -385,7 +386,7 @@ sub underlinethickness { return( $_[0]->data->{underlinethickness} ); }
 
 =item $ascender = $font->ascender()
 
-Returns the fonts ascender value.
+Returns the font's ascender value.
 
 =cut
 
@@ -393,7 +394,7 @@ sub ascender { return( $_[0]->data->{ascender} ); }
 
 =item $descender = $font->descender()
 
-Returns the fonts descender value.
+Returns the font's descender value.
 
 =cut
 
@@ -479,7 +480,7 @@ sub mapByUni { return( $_[0]->data->{u2c}->{$_[1]} || 0 ); }
 
 =item $name = $font->glyphByUni $unicode
 
-Returns the glyphs name by the fonts unicode map.
+Returns the glyph's name by the fonts unicode map.
 B<BEWARE:> non-standard glyph-names are mapped onto
 the ms-symbol area (0xF000).
 
@@ -489,7 +490,7 @@ sub glyphByUni { return ( $_[0]->data->{u2n}->{$_[1]} || '.notdef' ); }
 
 =item $name = $font->glyphByEnc $char
 
-Returns the glyphs name by the fonts encoding map.
+Returns the glyph's name by the font's encoding map.
 
 =cut
 
@@ -501,7 +502,7 @@ sub glyphByEnc {
 
 =item $name = $font->glyphByMap $char
 
-Returns the glyphs name by the fonts default map.
+Returns the glyph's name by the font's default map.
 
 =cut
 
@@ -509,15 +510,15 @@ sub glyphByMap { return ( $_[0]->data->{char}->[$_[1]] ); }
 
 =item $width = $font->wxByGlyph $glyph
 
-Returns the glyphs width.
+Returns the glyph's width.
 
 =cut
 
-sub wxByGlyph 
+sub wxByGlyph
 {
     my $self=shift;
     my $val=shift;
-    my $ret=undef; 
+    my $ret=undef;
     if(ref($self->data->{wx}) eq 'HASH')
     {
     	$ret=$self->data->{wx}->{$val};
@@ -548,16 +549,16 @@ sub wxByGlyph
 
 =item $width = $font->wxByUni $uni
 
-Returns the unicodes width.
+Returns the unicode's width.
 
 =cut
 
-sub wxByUni 
-{ 
+sub wxByUni
+{
     my $self=shift;
     my $val=shift;
     my $gid=$self->glyphByUni($val);
-    my $ret=$self->data->{wx}->{$gid}; 
+    my $ret=$self->data->{wx}->{$gid};
    	if(!defined($ret))
    	{
    		$ret=$self->missingwidth;
@@ -571,15 +572,15 @@ sub wxByUni
 
 =item $width = $font->wxByEnc $char
 
-Returns the characters width based on the current encoding.
+Returns the character's width based on the current encoding.
 
 =cut
 
-sub wxByEnc 
+sub wxByEnc
 {
     my ($self,$e)=@_;
     my $g=$self->glyphByEnc($e);
-    my $ret=$self->data->{wx}->{$g}; 
+    my $ret=$self->data->{wx}->{$g};
    	if(!defined($ret))
    	{
    		$ret=$self->missingwidth;
@@ -593,7 +594,7 @@ sub wxByEnc
 
 =item $width = $font->wxByMap $char
 
-Returns the characters width based on the fonts default encoding.
+Returns the character's width based on the font's default encoding.
 
 =cut
 
@@ -601,7 +602,7 @@ sub wxByMap
 {
     my ($self,$m)=@_;
     my $g=$self->glyphByMap($m);
-    my $ret=$self->data->{wx}->{$g}; 
+    my $ret=$self->data->{wx}->{$g};
    	if(!defined($ret))
    	{
    		$ret=$self->missingwidth;
@@ -631,7 +632,7 @@ sub width {
 
     my $kern = $self->{-dokern} && ref($self->data->{kern});
     my $lastglyph='';
-    foreach my $n (unpack('C*',$text)) 
+    foreach my $n (unpack('C*',$text))
     {
         $widths_cache[$n] = $self->wxByEnc($n) unless defined $widths_cache[$n];
         $width += $widths_cache[$n];
@@ -682,7 +683,7 @@ sub utfByStr {
 
 =item $string = $font->strByUtf $utf8string
 
-Returns the encoded string from utf8-string based on the fonts encoding map.
+Returns the encoded string from utf8-string based on the font's encoding map.
 
 =cut
 
@@ -699,11 +700,11 @@ Returns a properly formatted representation of $text for use in the PDF.
 
 =cut
 
-sub textByStr 
+sub textByStr
 {
     my ($self,$text)=@_;
     my $newtext='';
-    if(is_utf8($text)) 
+    if(is_utf8($text))
     {
         $text=$self->strByUtf($text);
     }
@@ -714,20 +715,20 @@ sub textByStr
     return($newtext);
 }
 
-sub textByStrKern 
+sub textByStrKern
 {
     my ($self,$text)=@_;
     if($self->{-dokern} && ref($self->data->{kern}))
     {
         my $newtext=' ';
-        if(is_utf8($text)) 
+        if(is_utf8($text))
         {
             $text=$self->strByUtf($text);
         }
 
         my $lastglyph='';
         my $tBefore=0;
-        foreach my $n (unpack('C*',$text)) 
+        foreach my $n (unpack('C*',$text))
         {
             if(defined $self->data->{kern}->{$lastglyph.':'.$self->data->{e2n}->[$n]})
             {
@@ -753,7 +754,7 @@ sub textByStrKern
     }
 }
 
-sub text 
+sub text
 {
     my ($self,$text,$size,$ident)=@_;
 
