@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::timesbold;
 
-our $VERSION = '2.020'; # VERSION
+use strict;
+use warnings;
 
-$FONTDATA = {
+our $VERSION = '2.030'; # VERSION
+
+sub data { return {
     'fontname' => 'Times-Bold',
     'type' => 'Type1',
     'apiname' => 'TiBo',
@@ -510,4 +513,6 @@ $FONTDATA = {
         'fi' => '556',                           # U+0xFB01
         'fl' => '556',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
