@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::timesbolditalic;
 
-our $VERSION = '2.023'; # VERSION
+use strict;
+use warnings;
 
-$FONTDATA = {
+our $VERSION = '2.030'; # VERSION
+
+sub data { return {
     'fontname' => 'Times-BoldItalic',
     'type' => 'Type1',
     'apiname' => 'TiBoIt',
@@ -509,4 +512,6 @@ $FONTDATA = {
         'fi' => '556',                           # U+0xFB01
         'fl' => '556',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
