@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::verdana;
 
-our $VERSION = '2.020'; # VERSION
+use strict;
+use warnings;
 
-$FONTDATA = {
+our $VERSION = '2.030'; # VERSION
+
+sub data { return {
     'fontname' => 'Verdana',
     'type' => 'TrueType',
     'apiname' => 'Verd',
@@ -834,4 +837,6 @@ $FONTDATA = {
         'fi' => '625',                           # U+0xFB01
         'fl' => '625',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
