@@ -1,12 +1,12 @@
 package PDF::API2::Resource::XObject::Form::BarCode::int2of5;
 
-our $VERSION = '2.023'; # VERSION
-
 use base 'PDF::API2::Resource::XObject::Form::BarCode';
 
 use strict;
 use warnings;
 
+our $VERSION = '2.030'; # VERSION
+
 # Interleaved 2 of 5 Barcodes
 
 # Pairs of digits are encoded; the first digit is represented by five
@@ -19,7 +19,7 @@ sub new {
 
     my @bars = $self->encode($options{'-code'});
 
-    $self->drawbar([@bars]);
+    $self->drawbar([@bars], $options{'caption'});
 
     return $self;
 }
