@@ -1,14 +1,15 @@
 package PDF::API2::Resource::XObject::Image::GD;
 
-our $VERSION = '2.020'; # VERSION
-
 use base 'PDF::API2::Resource::XObject::Image';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.030'; # VERSION
+
 use PDF::API2::Util;
 use PDF::API2::Basic::PDF::Utils;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
 sub new {
     my ($class,$pdf,$obj,$name,@opts) = @_;
     my $self;
@@ -38,7 +39,7 @@ sub read_gd {
     my $self = shift @_;
     my $gd = shift @_;
     my %opts = @_;
-    
+
     my ($w,$h) = $gd->getBounds();
     my $c = $gd->colorsTotal();
 
@@ -48,13 +49,13 @@ sub read_gd {
     $self->bpc(8);
     $self->colorspace('DeviceRGB');
 
-    if(UNIVERSAL::can($gd,'jpeg') && ($c > 256) && !$opts{-lossless}) {
+    if($gd->can('jpeg') && ($c > 256) && !$opts{-lossless}) {
 
         $self->filters('DCTDecode');
         $self->{' nofilt'}=1;
         $self->{' stream'}=$gd->jpeg(75);
 
-    } elsif(UNIVERSAL::can($gd,'raw')) {
+    } elsif($gd->can('raw')) {
 
         $self->filters('FlateDecode');
         $self->{' stream'}=$gd->raw;
