@@ -1,9 +1,12 @@
 package PDF::API2::Resource::XObject::Image::PNG;
 
-our $VERSION = '2.022'; # VERSION
-
 use base 'PDF::API2::Resource::XObject::Image';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.030'; # VERSION
+
 use Compress::Zlib;
 use POSIX qw(ceil floor);
 
@@ -11,8 +14,6 @@ use IO::File;
 use PDF::API2::Util;
 use PDF::API2::Basic::PDF::Utils;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
 sub new {
     my ($class,$pdf,$file,$name,%opts) = @_;
     my $self;
@@ -25,12 +26,15 @@ sub new {
     $self->{' apipdf'}=$pdf;
 
     my $fh = IO::File->new;
-    open($fh,$file);
-    binmode($fh,':raw');
+    if (ref($file)) {
+        $fh = $file;
+    }
+    else {
+        open $fh, "<", $file or die "$!: $file";
+    }
+    binmode $fh, ':raw';
 
     my ($buf,$l,$crc,$w,$h,$bpc,$cs,$cm,$fm,$im,$palete,$trns);
-    open($fh,$file);
-    binmode($fh);
     seek($fh,8,0);
     $self->{' stream'}='';
     $self->{' nofilt'}=1;
