@@ -1,22 +1,22 @@
 package PDF::API2::Util;
 
-our $VERSION = '2.025'; # VERSION
-
+use strict;
 no warnings qw[ recursion uninitialized ];
 
+our $VERSION = '2.030'; # VERSION
+
 BEGIN {
 
     use Encode qw(:all);
 
     use vars qw(
-        @ISA 
-        @EXPORT 
-        @EXPORT_OK 
-        %colors 
-        $key_var 
-        $key_var2 
-        %u2n 
-        %n2u 
+        @ISA
+        @EXPORT
+        @EXPORT_OK
+        %colors
+        $key_var
+        %u2n
+        %n2u
         $pua
         %PaperSizes
     );
@@ -62,7 +62,6 @@ BEGIN {
     no warnings qw[ recursion uninitialized ];
 
     $key_var='CBA';
-    $key_var2=0;
 
     $pua=0xE000;
 
@@ -81,8 +80,7 @@ sub digestx {
     my $mdkey='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789gT';
     my $xdata="0" x $len;
     my $off=0;
-    my $set;
-    foreach $set (0..(length($ddata)<<1)) {
+    foreach my $set (0..(length($ddata)<<1)) {
         $off+=vec($ddata,$set,4);
         $off+=vec($xdata,($set & $mask),8);
         vec($xdata,($set & ($mask<<1 |1)),4)=vec($mdkey,($off & 0x7f),4);
@@ -238,9 +236,9 @@ sub _HSVtoRGB { # test
         ## achromatic (grey)
         return ($v,$v,$v);
     }
-    
+
     $h %= 360;
-    
+
     $r = 2*cos(deg2rad($h));
     $g = 2*cos(deg2rad($h+120));
     $b = 2*cos(deg2rad($h+240));
@@ -249,7 +247,7 @@ sub _HSVtoRGB { # test
     $q = min($r,$g,$b);
     ($p,$q) = map { ($_<0 ? 0 : ($_>1 ? 1 : $_)) } ($p,$q);
     $f = $p - $q;
-    
+
     #if($p>=$v) {
     #    ($r,$g,$b) = map { $_*$v/$p } ($r,$g,$b);
     #} else {
@@ -267,7 +265,7 @@ sub _HSVtoRGB { # test
     return ($r,$g,$b);
 }
 
-sub RGBquant ($$$) {
+sub RGBquant {
     my($q1,$q2,$h)=@_;
     while($h<0){$h+=360;}
     $h%=360;
@@ -542,15 +540,15 @@ sub namecolor_lab {
     }
 }
 
-sub unfilter 
+sub unfilter
 {
     my ($filter,$stream)=@_;
 
-    if(defined $filter) 
+    if(defined $filter)
     {
         # we need to fix filter because it MAY be
         # an array BUT IT COULD BE only a name
-        if(ref($filter)!~/Array$/) 
+        if(ref($filter)!~/Array$/)
         {
                $filter = PDFArray($filter);
         }
@@ -560,7 +558,7 @@ sub unfilter
 
         @filts=(map { ("PDF::API2::Basic::PDF::Filter::".($_->val))->new } $filter->elementsof);
 
-        foreach my $f (@filts) 
+        foreach my $f (@filts)
         {
             $stream = $f->infilt($stream, 1);
         }
@@ -672,36 +670,8 @@ PDF::API2::Util - utility package for often use methods across the package.
 
 =item %sizes = getPaperSizes();
 
-Will retrieve the registered paper sizes of PDF::API2.
-
-    print Dumper(\%sizes);
-    $VAR1={
-        '4a'         =>  [ 4760  , 6716  ],
-        '2a'         =>  [ 3368  , 4760  ],
-        'a0'         =>  [ 2380  , 3368  ],
-        'a1'         =>  [ 1684  , 2380  ],
-        'a2'         =>  [ 1190  , 1684  ],
-        'a3'         =>  [ 842   , 1190  ],
-        'a4'         =>  [ 595   , 842   ],
-        'a5'         =>  [ 421   , 595   ],
-        'a6'         =>  [ 297   , 421   ],
-        '4b'         =>  [ 5656  , 8000  ],
-        '2b'         =>  [ 4000  , 5656  ],
-        'b0'         =>  [ 2828  , 4000  ],
-        'b1'         =>  [ 2000  , 2828  ],
-        'b2'         =>  [ 1414  , 2000  ],
-        'b3'         =>  [ 1000  , 1414  ],
-        'b4'         =>  [ 707   , 1000  ],
-        'b5'         =>  [ 500   , 707   ],
-        'b6'         =>  [ 353   , 500   ],
-        'letter'     =>  [ 612   , 792   ],
-        'broadsheet' =>  [ 1296  , 1584  ],
-        'ledger'     =>  [ 1224  , 792   ],
-        'tabloid'    =>  [ 792   , 1224  ],
-        'legal'      =>  [ 612   , 1008  ],
-        'executive'  =>  [ 522   , 756   ],
-        '36x36'      =>  [ 2592  , 2592  ],
-    };
+Returns a hash containing the available paper size aliases as keys and
+their dimensions as a two-element array reference.
 
 =back
 
